==> material-ui-shell-1.1.12.tgz: package/es/containers/LayoutContainer/LayoutContainer.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import { useConfig } from 'base-shell/lib/providers/Config';
import CssBaseline from '@material-ui/core/CssBaseline';
import PWAPrompt from 'react-ios-pwa-prompt';
import React from 'react';
import { useTheme } from 'material-ui-shell/lib/providers/Theme';
import UpdateContainer from 'material-ui-shell/lib/containers/UpdateContainer/UpdateContainer';
import QuestionDialogsProvider from 'material-ui-shell/lib/providers/Dialogs/Question/Provider';
import getThemeSource from 'material-ui-shell/lib/utils/theme';
import { SnackbarProvider } from 'notistack';
import { ThemeProvider } from '@material-ui/core/styles';
import { useIntl } from 'react-intl';
import FilterProvider from 'material-ui-shell/lib/providers/Filter/Provider';
export default function (_ref) {
  var children = _ref.children;
  var intl = useIntl();

  var _useConfig = useConfig(),
      appConfig = _useConfig.appConfig;

  var _useTheme = useTheme(),
      themeID = _useTheme.themeID,
      type = _useTheme.type;

  var _ref2 = appConfig || {},
      themeConfig = _ref2.theme,
      pwa = _ref2.pwa,
      notistack = _ref2.notistack;

  var _ref3 = pwa || {},
      useiOSPWAPrompt = _ref3.useiOSPWAPrompt,
      iOSPWAPromptProps = _ref3.iOSPWAPromptProps;

  var _ref4 = themeConfig || {},
      _ref4$themes = _ref4.themes,
      themes = _ref4$themes === void 0 ? [] : _ref4$themes;

  var theme = getThemeSource(themeID, themes, type);
  return /*#__PURE__*/React.createElement(ThemeProvider, {
    theme: theme
  }, /*#__PURE__*/React.createElement(CssBaseline, null), /*#__PURE__*/React.createElement(SnackbarProvider, _extends({
    maxSnack: 3
  }, notistack), /*#__PURE__*/React.createElement(UpdateContainer, null, /*#__PURE__*/React.createElement(QuestionDialogsProvider, null, /*#__PURE__*/React.createElement(FilterProvider, null, children)))), useiOSPWAPrompt && /*#__PURE__*/React.createElement(PWAPrompt //debug={true}
  , _extends({
    promptOnVisit: 1,
    timesToShow: 3,
    copyTitle: intl.formatMessage({
      id: 'ios_prompt_title',
      defaultMessage: 'Add to Home Screen'
    }),
    copyClosePrompt: intl.formatMessage({
      id: 'ios_prompt_close',
      defaultMessage: 'Close'
    }),
    copyBody: intl.formatMessage({
      id: 'ios_prompt_body',
      defaultMessage: 'This website has app functionality. Add it to your home screen to use it in fullscreen and while offline.'
    }),
    copyShareButtonLabel: intl.formatMessage({
      id: 'ios_prompt_share_button',
      defaultMessage: "1) Press the 'Share' button"
    }),
    copyAddHomeButtonLabel: intl.formatMessage({
      id: 'ios_prompt_add_to_home_button',
      defaultMessage: "2) Press 'Add to Home Screen'"
    }),
    permanentlyHideOnDismiss: false
  }, iOSPWAPromptProps)));
}

==> material-ui-shell-1.1.17.tgz: package/es/containers/LayoutContainer/LayoutContainer.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import { useConfig } from 'base-shell/lib/providers/Config';
import CssBaseline from '@material-ui/core/CssBaseline';
import PWAPrompt from 'react-ios-pwa-prompt';
import React from 'react';
import { useTheme } from 'material-ui-shell/lib/providers/Theme';
import UpdateContainer from 'material-ui-shell/lib/containers/UpdateContainer/UpdateContainer';
import QuestionDialogsProvider from 'material-ui-shell/lib/providers/Dialogs/Question/Provider';
import getThemeSource from 'material-ui-shell/lib/utils/theme';
import { SnackbarProvider } from 'notistack';
import { ThemeProvider } from '@material-ui/core/styles';
import { useIntl } from 'react-intl';
import FilterProvider from 'material-ui-shell/lib/providers/Filter/Provider';
import VirtualListsProvider from 'material-ui-shell/lib/providers/VirtualLists/Provider';
export default function (_ref) {
  var children = _ref.children;
  var intl = useIntl();

  var _useConfig = useConfig(),
      appConfig = _useConfig.appConfig;

  var _useTheme = useTheme(),
      themeID = _useTheme.themeID,
      type = _useTheme.type;

  var _ref2 = appConfig || {},
      themeConfig = _ref2.theme,
      pwa = _ref2.pwa,
      notistack = _ref2.notistack;

  var _ref3 = pwa || {},
      useiOSPWAPrompt = _ref3.useiOSPWAPrompt,
      iOSPWAPromptProps = _ref3.iOSPWAPromptProps;

  var _ref4 = themeConfig || {},
      _ref4$themes = _ref4.themes,
      themes = _ref4$themes === void 0 ? [] : _ref4$themes;

  var theme = getThemeSource(themeID, themes, type);
  return /*#__PURE__*/React.createElement(ThemeProvider, {
    theme: theme
  }, /*#__PURE__*/React.createElement(CssBaseline, null), /*#__PURE__*/React.createElement(SnackbarProvider, _extends({
    maxSnack: 3
  }, notistack), /*#__PURE__*/React.createElement(UpdateContainer, null, /*#__PURE__*/React.createElement(QuestionDialogsProvider, null, /*#__PURE__*/React.createElement(FilterProvider, null, /*#__PURE__*/React.createElement(VirtualListsProvider, null, children))))), useiOSPWAPrompt && /*#__PURE__*/React.createElement(PWAPrompt //debug={true}
  , _extends({
    promptOnVisit: 1,
    timesToShow: 3,
    copyTitle: intl.formatMessage({
      id: 'ios_prompt_title',
      defaultMessage: 'Add to Home Screen'
    }),
    copyClosePrompt: intl.formatMessage({
      id: 'ios_prompt_close',
      defaultMessage: 'Close'
    }),
    copyBody: intl.formatMessage({
      id: 'ios_prompt_body',
      defaultMessage: 'This website has app functionality. Add it to your home screen to use it in fullscreen and while offline.'
    }),
    copyShareButtonLabel: intl.formatMessage({
      id: 'ios_prompt_share_button',
      defaultMessage: "1) Press the 'Share' button"
    }),
    copyAddHomeButtonLabel: intl.formatMessage({
      id: 'ios_prompt_add_to_home_button',
      defaultMessage: "2) Press 'Add to Home Screen'"
    }),
    permanentlyHideOnDismiss: false
  }, iOSPWAPromptProps)));
}
